summaryrefslogtreecommitdiffstats
path: root/buildtools/custommakefiles/customprojectpart.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit32b67ac0690de411b26b1d5e715b188c27442248 (patch)
tree43167816a3df6b3a877d71c9a7963ed270dcc8c9 /buildtools/custommakefiles/customprojectpart.cpp
parent330c33ab6f97b279737bf9527c9add7bb1475450 (diff)
downloadtdevelop-32b67ac0690de411b26b1d5e715b188c27442248.tar.gz
tdevelop-32b67ac0690de411b26b1d5e715b188c27442248.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'buildtools/custommakefiles/customprojectpart.cpp')
-rw-r--r--buildtools/custommakefiles/customprojectpart.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/buildtools/custommakefiles/customprojectpart.cpp b/buildtools/custommakefiles/customprojectpart.cpp
index 67a56ce0..50d69800 100644
--- a/buildtools/custommakefiles/customprojectpart.cpp
+++ b/buildtools/custommakefiles/customprojectpart.cpp
@@ -65,8 +65,8 @@ typedef KDevGenericFactory<CustomProjectPart> CustomProjectFactory;
static const KDevPluginInfo data( "kdevcustomproject" );
K_EXPORT_COMPONENT_FACTORY( libkdevcustomproject, CustomProjectFactory( data ) )
-CustomProjectPart::CustomProjectPart( TQObject *tqparent, const char *name, const TQStringList & )
- : KDevBuildTool( &data, tqparent, name ? name : "CustomProjectPart" )
+CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const TQStringList & )
+ : KDevBuildTool( &data, parent, name ? name : "CustomProjectPart" )
, m_lastCompilationFailed( false ), m_recursive( false ), m_first_recursive( false )
{
setInstance( CustomProjectFactory::instance() );
@@ -512,7 +512,7 @@ void CustomProjectPart::findNewFiles( const TQString& dir, TQStringList& filelis
// If the entry is blacklisted, proceed to next one.
// Note that by using generic isInBlacklist(),
// we are actually wasting resources,
// because it also tests whether any tqparent directory of relativeEntry is blacklisted.
// But by the order we are traversing and processing the directories,
// we know it is not the case, ever.
if ( isInBlacklist( relativeEntry ) )
@@ -512,7 +512,7 @@ void CustomProjectPart::findNewFiles( const TQString& dir, TQStringList& filelis
// Note that by using generic isInBlacklist(),
// we are actually wasting resources,
- // because it also tests whether any tqparent directory of relativeEntry is blacklisted.
+ // because it also tests whether any parent directory of relativeEntry is blacklisted.
// But by the order we are traversing and processing the directories,
// we know it is not the case, ever.